{#
# This file is part of Invenio.
# Copyright (C) 2014, 2015 CERN.
#
# Invenio is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
#}

{# Collect the nav links, forms, and other content for toggling #}
<form name="search" action="{{ url_for('search.search') }}" method="get" role="search" id="searchform">
{%- block search_form_ctrls -%}
  <input type="hidden" name="ln" value="{{g.ln}}">
  {%- if collection.id > 1 %}
  <input type="hidden" name="cc" value="{{collection.name}}">
  {%- endif %}
  <input type="hidden" name="post_filter" value="{{request.args.get('post_filter', '')}}">
  <div class="nav navbar-nav navbar-left navbar-form">
    <div class="input-group" id="searchform-input-group">
      {% include "search/form/tips.html" %}
      {% include "search/form/controls.html" %}
    </div>
  </div>
{%- endblock -%}
  {% include "search/form/dropdown.html" %}
</form>
