{#
# This file is part of Invenio.
# Copyright (C) 2014 CERN.
#
# Invenio is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
#}

{%- from "search/helpers.html" import search_box with context -%}

{%- block search_form_dropbox_boxes -%}
<div class="nav navbar-nav navbar-row">
  <div id="navbar-bottom" class="collapse">
    <div class="row navbar-row-container">
      <div class="col-md-12">
        {# This is done using document.write to hide it from non-JS users #}
        <script type="text/javascript">
          var box = {{ search_box(collection, easy_search_form)|tojson|safe }};
          document.write(box);
        </script>
      </div>
    </div>
  </div>
</div>
{%- endblock -%}
