/*
 * This file is part of Invenio.
 * Copyright (C) 2014, 2015 CERN.
 *
 * Invenio is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * Invenio is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Invenio; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

#search-label {
  font-size: 14px;
}

/* ----------------------- */

.nav.nav-pill-gray > .active > a,
.nav.nav-pill-gray > li > a:hover {
  background: none;
  text-decoration: underline;
  color: inherit;
}

/* line below the tab bar */

._tab-form-group {
  border-bottom: 1px solid #e7e7e7;
}

._tab-form-group .nav-tabs {
  border-bottom: none;
}

/* -------------- */

/*
to make "add to search" form look consistent
in much shrinked window

values copied from bootstrap ones for higher than xs size counterparts -> to be unified using "less"
*/

.navbar-collapse {
  border-top: none;
}

.navbar-collapse .navbar-nav.navbar-left:first-child {
  margin-left: -15px;
}

.navbar-form {
  padding-top: 0;
  padding-bottom: 0;
  margin-right: 0;
  margin-left: 0;
  border: 0;
}

/* ------------ */

.navbar-row {
  width: 100%;
  margin: inherit;
}

.navbar-row .navbar-row-container {
  /* same colour as navbar border*/
  border-top: 1px solid #e7e7e7;
  padding-top: 20px;
  padding-bottom: 20px;
}

.navbar-collapse {
  max-height: none;
}

/*
  prevents thick (double) borders around buttons
  standing next to each other
*/
.input-group-btn > .btn + .btn,
.input-group-btn > .btn {
  margin-left: -1px;
}

/* to prevent shrinking search field after applying typeahead */
.navbar-form .input-group .form-control {
  width: 100%;
}

.navbar-form .input-group .input-group-btn {
  width: 1%;
}

/* fix portalbox text overflow (see issue#3023 */
.panel-body {
  word-wrap: break-word;
}

/*
  too keep searchbar with buttons in one line
*/
@media (min-width: 768px) { /* ld size */
  #searchform-input-group {
    width: 670px;
  }
}

@media (min-width: 992px) { /* md size */
  #searchform-input-group {
    width: 710px;
  }
}

@media (min-width: 1200px) { /* ld size */
  #searchform-input-group {
    width: 915px;
  }
}
